pub enum CpuDecodeParallelism {
Auto,
Serial,
}Expand description
CPU parallelism policy for native JPEG 2000 decode.
Variants
Auto
Allow a single tile decode to use internal code-block parallelism.
Serial
Keep code-block decode serial for callers that already parallelize tiles.