#[non_exhaustive]pub enum DecodingError {
CodeBlockDecodeFailure,
UnsupportedFeature(&'static str),
TooManyBitplanes,
TooManyCodingPasses,
InvalidBitplaneCount,
InvalidPrecinct,
InvalidProgressionIterator,
UnexpectedEof,
OutputBufferTooSmall,
}Expand description
Errors related to decoding operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CodeBlockDecodeFailure
An error occurred while decoding a code-block.
UnsupportedFeature(&'static str)
The codestream uses a feature that this decoder does not implement yet.
TooManyBitplanes
Number of bitplanes in a code-block is too large.
TooManyCodingPasses
A code-block contains too many coding passes.
InvalidBitplaneCount
Invalid number of bitplanes in a code-block.
InvalidPrecinct
A precinct was invalid.
InvalidProgressionIterator
A progression iterator ver invalid.
UnexpectedEof
Unexpected end of data.
OutputBufferTooSmall
Caller-provided output buffer is too small for the decoded image.