#[non_exhaustive]pub enum DirectPlanUnsupportedReason {
GrayscaleImageWithoutAlpha,
GrayscaleSingleTileCodestream,
GrayscaleSingleComponentCodestream,
ColorRgbImageWithoutAlpha,
ColorSingleTileCodestream,
ColorThreeComponentRgbCodestream,
RgbaRgbImageWithAlpha,
RgbaFourComponentRgbCodestream,
ComponentIndexOutOfRange,
ComponentUnitSampled,
ComponentDecompositionIndexOutOfRange,
MixedCodeBlockCoding,
}Expand description
Structured reasons why a direct JPEG 2000 device plan cannot be built.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
GrayscaleImageWithoutAlpha
Grayscale direct plans require grayscale images without alpha.
GrayscaleSingleTileCodestream
Grayscale direct plans require a single-tile codestream.
GrayscaleSingleComponentCodestream
Grayscale direct plans require a single-component codestream.
ColorRgbImageWithoutAlpha
Color direct plans require RGB images without alpha.
ColorSingleTileCodestream
Color direct plans require a single-tile codestream.
ColorThreeComponentRgbCodestream
Color direct plans require three RGB components.
RgbaRgbImageWithAlpha
RGBA direct plans require an RGB image with explicit alpha.
RgbaFourComponentRgbCodestream
RGBA direct plans require four components in semantic R, G, B, A order.
ComponentIndexOutOfRange
A direct component plan index did not exist.
ComponentUnitSampled
Direct component plans require unit-sampled components.
ComponentDecompositionIndexOutOfRange
A direct component decomposition index did not exist.
MixedCodeBlockCoding
Direct device plans do not yet represent classic and HT code-blocks in one sub-band.