#[non_exhaustive]pub enum J2kCodestreamHeaderError {
TooShort {
need: usize,
have: usize,
},
TruncatedAt {
offset: usize,
segment: &'static str,
},
InvalidMarker {
offset: usize,
marker: u8,
},
MissingRequiredMarker {
marker: &'static str,
},
InvalidSegment {
offset: usize,
what: &'static str,
},
InvalidSiz {
what: &'static str,
},
InvalidCod {
what: &'static str,
},
Unsupported {
what: &'static str,
},
}Expand description
Error returned by inspect_j2k_codestream_header.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooShort
Input was shorter than the required prefix.
TruncatedAt
Input ended while reading a marker or marker segment.
Fields
InvalidMarker
A codestream marker did not start with 0xFF.
Fields
MissingRequiredMarker
A required codestream marker was absent.
InvalidSegment
A generic marker segment was malformed.
Fields
InvalidSiz
The SIZ marker segment was malformed or unsupported.
InvalidCod
The COD marker segment was malformed or unsupported.
Unsupported
The header is valid, but outside the public inspection contract.