pub fn encode_htj2k(
pixels: &[u8],
width: u32,
height: u32,
num_components: u16,
bit_depth: u8,
signed: bool,
options: &EncodeOptions,
) -> EncodeResult<Vec<u8>>Expand description
Encode pixel data into an HTJ2K codestream.
Lossless HTJ2K output is self-validated before it is returned.
Errors
Returns an error when the input or options are invalid, encoding fails, or the requested output fails HTJ2K self-validation.