forward_ict_reference

Function forward_ict_reference 

pub fn forward_ict_reference(planes: Vec<Vec<f32>>) -> Vec<Vec<f32>>
Adapter scalar forward ICT reference for Metal/CUDA stage parity.

Applies the native CPU forward Irreversible Color Transform to three component planes supplied as owned Vec<f32> arrays. The transform is applied in place and the mutated planes are returned.