pub struct EncodedJ2kCodeBlock {
pub data: Vec<u8>,
pub segments: Vec<J2kCodeBlockSegment>,
pub number_of_coding_passes: u8,
pub missing_bit_planes: u8,
}Expand description
Adapter encoded classic J2K code-block payload for backend experimentation.
Fields
data: Vec<u8>Combined payload bytes for all coded segments in this code block.
segments: Vec<J2kCodeBlockSegment>Coded segments for the code block.
number_of_coding_passes: u8Number of coding passes present for this code block.
missing_bit_planes: u8Missing most-significant bit planes for this code block.