pub struct HtOwnedCodeBlockBatchJob {Show 15 fields
pub output_x: u32,
pub output_y: u32,
pub data: Vec<u8>,
pub cleanup_length: u32,
pub refinement_length: u32,
pub width: u32,
pub height: u32,
pub output_stride: usize,
pub missing_bit_planes: u8,
pub number_of_coding_passes: u8,
pub num_bitplanes: u8,
pub roi_shift: u8,
pub stripe_causal: bool,
pub strict: bool,
pub dequantization_step: f32,
}Expand description
Adapter owned HTJ2K batched code-block decode job.
Fields
output_x: u32X offset within the target sub-band coefficient buffer.
output_y: u32Y offset within the target sub-band coefficient buffer.
data: Vec<u8>Combined cleanup/refinement bytes for the code block.
cleanup_length: u32Cleanup segment length in bytes.
refinement_length: u32Refinement segment length in bytes.
width: u32Code-block width in samples.
height: u32Code-block height in samples.
output_stride: usizeOutput row stride, in samples, for the target sub-band storage.
missing_bit_planes: u8Missing most-significant bit planes for this code block.
number_of_coding_passes: u8Number of coding passes present for this code block.
num_bitplanes: u8Total coded bitplanes for the parent sub-band.
roi_shift: u8Region-of-interest maxshift value from RGN marker metadata.
stripe_causal: boolWhether vertically causal context was enabled.
strict: boolWhether strict decode validation is enabled for the parent image.
dequantization_step: f32Dequantization step to apply to decoded coefficients.