pub struct J2kOwnedCodeBlockBatchJob {Show 15 fields
pub output_x: u32,
pub output_y: u32,
pub data: Vec<u8>,
pub segments: Vec<J2kCodeBlockSegment>,
pub width: u32,
pub height: u32,
pub output_stride: usize,
pub missing_bit_planes: u8,
pub number_of_coding_passes: u8,
pub total_bitplanes: u8,
pub roi_shift: u8,
pub sub_band_type: J2kSubBandType,
pub style: J2kCodeBlockStyle,
pub strict: bool,
pub dequantization_step: f32,
}Expand description
Adapter owned classic J2K batched code-block decode job.
Fields
output_x: u32X offset within the target sub-band coefficient buffer.
output_y: u32Y offset within the target sub-band coefficient buffer.
data: Vec<u8>Combined payload bytes for all coded segments in this code block.
segments: Vec<J2kCodeBlockSegment>Coded segments for the code block.
width: u32Code-block width in samples.
height: u32Code-block height in samples.
output_stride: usizeOutput row stride, in samples, for the target sub-band storage.
missing_bit_planes: u8Missing most-significant bit planes for this code block.
number_of_coding_passes: u8Number of coding passes present for this code block.
total_bitplanes: u8Total coded bitplanes for the parent sub-band.
roi_shift: u8Region-of-interest maxshift value from RGN marker metadata.
sub_band_type: J2kSubBandTypeThe sub-band type containing this code block.
style: J2kCodeBlockStyleThe code-block style flags.
strict: boolWhether strict decode validation is enabled for the parent image.
dequantization_step: f32Dequantization step to apply to decoded coefficients.