J2kPacketizationCodeBlock

Struct J2kPacketizationCodeBlock 

pub struct J2kPacketizationCodeBlock<'a> {
    pub data: &'a [u8],
    pub ht_cleanup_length: u32,
    pub ht_refinement_length: u32,
    pub num_coding_passes: u8,
    pub num_zero_bitplanes: u8,
    pub previously_included: bool,
    pub l_block: u32,
    pub block_coding_mode: J2kPacketizationBlockCodingMode,
}
Adapter LRCP packetization code-block contribution for backend experimentation.

Fields

data: &'a [u8]

Encoded Tier-1 bitstream bytes for this packet contribution.

ht_cleanup_length: u32

HTJ2K cleanup segment length in bytes when using high-throughput coding.

ht_refinement_length: u32

HTJ2K refinement segment length in bytes when using high-throughput coding.

num_coding_passes: u8

Number of coding passes in this contribution.

num_zero_bitplanes: u8

Number of zero most-significant bitplanes before first inclusion.

previously_included: bool

Whether this code-block was included in a previous packet.

l_block: u32

L-block value used for segment length coding.

block_coding_mode: J2kPacketizationBlockCodingMode

Block coder used for this contribution.