pub struct NativeComponentPlane { /* private fields */ }Expand description
One owned decoded component plane at native bit depth.
Implementations
Sourceimpl NativeComponentPlane
impl NativeComponentPlane
Sourcepub fn data(&self) -> &[u8] ⓘ
pub fn data(&self) -> &[u8] ⓘ
Packed little-endian sample bytes for this component in row-major order.
Sourcepub fn dimensions(&self) -> (u32, u32)
pub fn dimensions(&self) -> (u32, u32)
Width and height of this decoded plane in output samples.
Sourcepub fn sampling(&self) -> (u8, u8)
pub fn sampling(&self) -> (u8, u8)
Horizontal and vertical SIZ sampling factors (XRsiz, YRsiz) for
the source component represented by this plane.
Sourcepub fn bytes_per_sample(&self) -> u8
pub fn bytes_per_sample(&self) -> u8
Bytes used for each packed little-endian sample in Self::data.