J2kCodestreamHeaderError

Enum J2kCodestreamHeaderError 

#[non_exhaustive]
pub enum J2kCodestreamHeaderError { TooShort { need: usize, have: usize, }, TruncatedAt { offset: usize, segment: &'static str, }, InvalidMarker { offset: usize, marker: u8, }, MissingRequiredMarker { marker: &'static str, }, InvalidSegment { offset: usize, what: &'static str, }, InvalidSiz { what: &'static str, }, InvalidCod { what: &'static str, }, Unsupported { what: &'static str, }, }
Error returned by inspect_j2k_codestream_header.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TooShort

Input was shorter than the required prefix.

Fields

need: usize

Required byte count.

have: usize

Available byte count.



TruncatedAt

Input ended while reading a marker or marker segment.

Fields

offset: usize

Byte offset where the truncated segment begins.

segment: &'static str

Segment being read.



InvalidMarker

A codestream marker did not start with 0xFF.

Fields

offset: usize

Byte offset of the invalid marker.

marker: u8

Byte found where the marker code was expected.



MissingRequiredMarker

A required codestream marker was absent.

Fields

marker: &'static str

Missing marker name.



InvalidSegment

A generic marker segment was malformed.

Fields

offset: usize

Byte offset of the segment length.

what: &'static str

Description of the invalid segment.



InvalidSiz

The SIZ marker segment was malformed or unsupported.

Fields

what: &'static str

Description of the invalid SIZ segment.



InvalidCod

The COD marker segment was malformed or unsupported.

Fields

what: &'static str

Description of the invalid COD segment.



Unsupported

The header is valid, but outside the public inspection contract.

Fields

what: &'static str

Description of the unsupported feature.