pub struct DecodeSettings {
pub resolve_palette_indices: bool,
pub strict: bool,
pub target_resolution: Option<(u32, u32)>,
}Expand description
Settings to apply during decoding.
Fields
resolve_palette_indices: boolWhether palette indices should be resolved.
JPEG2000 images can be stored in two different ways. First, by storing RGB values (depending on the color space) for each pixel. Secondly, by only storing a single index for each channel, and then resolving the actual color using the index.
If you disable this option, in case you have an image with palette indices, they will not be resolved, but instead a grayscale image will be returned, with each pixel value corresponding to the palette index of the location.
strict: boolWhether strict mode should be enabled when decoding.
It is recommended to leave this flag disabled, unless you have a specific reason not to.
target_resolution: Option<(u32, u32)>A hint for the target resolution that the image should be decoded at.