pub struct DecoderWorkspaceStats { /* private fields */ }Expand description
Observable counters and retained ownership for a reusable decoder workspace.
Implementations
Sourceimpl DecoderWorkspaceStats
impl DecoderWorkspaceStats
Sourcepub const fn decode_calls(self) -> u64
pub const fn decode_calls(self) -> u64
Number of native image decode calls made with this workspace.
Sourcepub const fn component_owner_reuses(self) -> u64
pub const fn component_owner_reuses(self) -> u64
Number of calls that began with reusable decoded-component owners.
Sourcepub const fn tier1_owner_reuses(self) -> u64
pub const fn tier1_owner_reuses(self) -> u64
Number of calls that began with reusable Tier-1 allocations.
Sourcepub const fn idwt_owner_reuses(self) -> u64
pub const fn idwt_owner_reuses(self) -> u64
Number of calls that began with reusable IDWT allocations.
Sourcepub const fn scratch_capacity_retries(self) -> u64
pub const fn scratch_capacity_retries(self) -> u64
Number of retained-scratch evictions followed by a fresh retry.
Sourcepub const fn retained_component_bytes(self) -> usize
pub const fn retained_component_bytes(self) -> usize
Retained component-owner capacity after the most recent completed core decode.
Sourcepub const fn retained_tier1_bytes(self) -> usize
pub const fn retained_tier1_bytes(self) -> usize
Retained classic and HT Tier-1 capacity after the most recent call.
Sourcepub const fn retained_idwt_bytes(self) -> usize
pub const fn retained_idwt_bytes(self) -> usize
Retained floating-point and exact-integer IDWT capacity after the most recent call.
Sourcepub const fn retained_scratch_bytes(self) -> usize
pub const fn retained_scratch_bytes(self) -> usize
Total retained lifetime-free decode scratch after the most recent call.