pub struct HtCleanupEncodeDistribution {Show 14 fields
pub total_quads: u64,
pub initial_quads: u64,
pub non_initial_quads: u64,
pub rho_counts: [u64; 16],
pub initial_rho_counts: [u64; 16],
pub non_initial_rho_counts: [u64; 16],
pub non_initial_u_q_counts: [u64; 32],
pub non_initial_e_qmax_counts: [u64; 32],
pub non_initial_kappa_counts: [u64; 32],
pub non_initial_rho_u_q_counts: [[u64; 32]; 16],
pub mag_sign_calls: u64,
pub mag_sign_rho_counts: [u64; 16],
pub mag_sign_sample_bit_counts: [u64; 32],
pub mag_sign_encoded_samples: u64,
}Expand description
Adapter HTJ2K cleanup-encode shape counters for backend benchmarking.
Fields
total_quads: u64Total 2x2 cleanup quads visited.
initial_quads: u64Quads encoded in the first cleanup row pair.
non_initial_quads: u64Quads encoded after the first cleanup row pair.
rho_counts: [u64; 16]All-quad rho histogram, indexed by the low four rho bits.
initial_rho_counts: [u64; 16]First-row-pair rho histogram, indexed by the low four rho bits.
non_initial_rho_counts: [u64; 16]Non-initial-row rho histogram, indexed by the low four rho bits.
non_initial_u_q_counts: [u64; 32]Non-initial-row u_q histogram.
non_initial_e_qmax_counts: [u64; 32]Non-initial-row e_qmax histogram.
non_initial_kappa_counts: [u64; 32]Non-initial-row kappa histogram.
non_initial_rho_u_q_counts: [[u64; 32]; 16]Non-initial-row joint rho/u_q histogram.
mag_sign_calls: u64Calls that emitted at least one magnitude/sign sample.
mag_sign_rho_counts: [u64; 16]Magnitude/sign call histogram, indexed by the low four rho bits.
mag_sign_sample_bit_counts: [u64; 32]Encoded magnitude/sign sample payload bit-count histogram.
mag_sign_encoded_samples: u64Number of individual magnitude/sign samples emitted.