J2kCodeBlockDecodeJob

Struct J2kCodeBlockDecodeJob 

pub struct J2kCodeBlockDecodeJob<'a> {
Show 13 fields pub data: &'a [u8], pub segments: &'a [J2kCodeBlockSegment], pub width: u32, pub height: u32, pub output_stride: usize, pub missing_bit_planes: u8, pub number_of_coding_passes: u8, pub total_bitplanes: u8, pub roi_shift: u8, pub sub_band_type: J2kSubBandType, pub style: J2kCodeBlockStyle, pub strict: bool, pub dequantization_step: f32,
}
Adapter classic J2K code-block job description for backend experimentation.

Fields

data: &'a [u8]

Combined payload bytes for all coded segments in this code block.

segments: &'a [J2kCodeBlockSegment]

Coded segments for the code block.

width: u32

Code-block width in samples.

height: u32

Code-block height in samples.

output_stride: usize

Output row stride, in samples, for the target sub-band storage.

missing_bit_planes: u8

Missing most-significant bit planes for this code block.

number_of_coding_passes: u8

Number of coding passes present for this code block.

total_bitplanes: u8

Total coded bitplanes for the parent sub-band.

roi_shift: u8

Region-of-interest maxshift value from RGN marker metadata.

sub_band_type: J2kSubBandType

The sub-band type containing this code block.

style: J2kCodeBlockStyle

The code-block style flags.

strict: bool

Whether strict decode validation is enabled for the parent image.

dequantization_step: f32

Dequantization step to apply to decoded coefficients.